package com.datacloudsec.utils;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Enumeration;
import java.util.Scanner;
import org.apache.commons.io.IOUtils;
import org.apache.log4j.Logger;
import org.smslib.IOutboundMessageNotification;
import org.smslib.OutboundMessage;
import org.smslib.Service;
import org.smslib.Message.MessageEncodings;
import org.smslib.helper.CommPortIdentifier;
import org.smslib.helper.SerialPort;
import org.smslib.modem.SerialModemGateway;

public class SmsUtil {

   private static final Logger LOG = Logger.getLogger(SmsUtil.class);
   private static SmsUtil instance;
   private Service srv = new Service();
   private SerialModemGateway serialModemGateway;


   public static synchronized SmsUtil getInstance() throws Exception {
      if(instance == null) {
         String smsPort = getSmsPort();
         if(smsPort == null) {
            throw new Exception("未获取到短信猫");
         }

         LOG.debug("使用端口：" + smsPort);
         if(!insertSimed(smsPort)) {
            throw new Exception("未插入SIM卡");
         }

         SmsUtil ins = new SmsUtil();

         try {
            ins.serialModemGateway = new SerialModemGateway("modem." + smsPort, smsPort, 9600, "datacloudsec", "17254");
            ins.serialModemGateway.setInbound(true);
            ins.serialModemGateway.setOutbound(true);
            ins.serialModemGateway.setSimPin("0000");
            ins.serialModemGateway.setOutboundNotification(new IOutboundMessageNotification() {
               public void process(String gatewayId, OutboundMessage msg) {
                  SmsUtil.LOG.debug(gatewayId + " = " + msg);
               }
            });
            ins.srv.addGateway(ins.serialModemGateway);
            ins.srv.startService();
            instance = ins;
         } catch (Exception var3) {
            ins.srv.stopService();
            throw var3;
         }
      }

      return instance;
   }

   public void send(String phone, String content) throws Exception {
      if(!this.serialModemGateway.isStarted()) {
         throw new Exception("短信猫异常");
      } else {
         LOG.debug("发送：" + content + " 到 " + phone);
         OutboundMessage msg = new OutboundMessage(phone, content);
         msg.setEncoding(MessageEncodings.ENCUCS2);
         this.srv.sendMessage(msg);
      }
   }

   public void stop() throws Exception {
      this.serialModemGateway.stopGateway();
      this.srv.stopService();
      instance = null;
   }

   private static boolean insertSimed(String port) {
      LOG.debug("测试" + port + "SIM卡");
      SerialPort sp = null;
      InputStream is = null;
      OutputStream os = null;

      try {
         CommPortIdentifier e = CommPortIdentifier.getPortIdentifier(port);
         sp = e.open("SMSLibCommTester", 1971);
         sp.setFlowControlMode(SerialPort.FLOWCONTROL_RTSCTS_IN);
         sp.setSerialPortParams(9600, SerialPort.DATABITS_8, SerialPort.STOPBITS_1, SerialPort.PARITY_NONE);
         sp.enableReceiveTimeout(1000);
         is = sp.getInputStream();
         os = sp.getOutputStream();
         readIs(is);
         writeOs(os, "AT+CIMI\r\n");
         Thread.sleep(1000L);
         String result = readIs(is);
         LOG.debug("result = " + result);
         if(result.contains("OK")) {
            return true;
         }
      } catch (Exception var15) {
         LOG.error("SIM卡测试出错", var15);
      } finally {
         IOUtils.closeQuietly(is);
         IOUtils.closeQuietly(os);
         if(sp != null) {
            try {
               sp.close();
            } catch (Exception var14) {
               ;
            }
         }

      }

      return false;
   }

   private static String getSmsPort() throws Exception {
      Enumeration portList = CommPortIdentifier.getPortIdentifiers();

      while(true) {
         CommPortIdentifier cp;
         do {
            if(!portList.hasMoreElements()) {
               return null;
            }

            cp = (CommPortIdentifier)portList.nextElement();
            LOG.debug("端口=" + cp.getName());
         } while(cp.getPortType() != CommPortIdentifier.PORT_SERIAL);

         LOG.debug("测试端口=" + cp.getName());
         SerialPort sp = null;
         InputStream is = null;
         OutputStream os = null;

         try {
            sp = cp.open("SMSLibCommTester", 1971);
            sp.setFlowControlMode(SerialPort.FLOWCONTROL_RTSCTS_IN);
            sp.setSerialPortParams(9600, SerialPort.DATABITS_8, SerialPort.STOPBITS_1, SerialPort.PARITY_NONE);
            sp.enableReceiveTimeout(1000);
            is = sp.getInputStream();
            os = sp.getOutputStream();
            readIs(is);
            writeOs(os, "AT\r");
            Thread.sleep(1000L);
            String e = readIs(is);
            if(e.contains("OK")) {
               String var7 = cp.getName();
               return var7;
            }
         } catch (Exception var16) {
            LOG.error("短息猫端口测试出错", var16);
         } finally {
            IOUtils.closeQuietly(is);
            IOUtils.closeQuietly(os);
            if(sp != null) {
               try {
                  sp.close();
               } catch (Exception var15) {
                  ;
               }
            }

         }
      }
   }

   private static String readIs(InputStream is) throws IOException {
      StringBuffer sb = new StringBuffer();

      int c;
      while((c = is.read()) != -1) {
         char ct = (char)c;
         sb.append(ct);
      }

      return sb.toString();
   }

   private static void writeOs(OutputStream os, String content) throws IOException {
      char[] var5;
      int var4 = (var5 = content.toCharArray()).length;

      for(int var3 = 0; var3 < var4; ++var3) {
         char c = var5[var3];
         os.write(c);
      }

      os.flush();
   }

   public static void main(String[] args) throws Exception {
      Scanner scanner = new Scanner(System.in);

      while(true) {
         while(true) {
            System.out.print("plase input:");
            String in = scanner.next();
            if(in.contains("exit")) {
               scanner.close();
               System.exit(0);
            } else if(in.contains("send")) {
               getInstance().send("15178832475", "java发送aaa");
            }
         }
      }
   }
}
